@@ -27,7 +27,7 @@ impl IPeriod for Period {
 
 #[allow(dead_code)]
 impl Period {
-    fn new() -> Period {
+    pub fn new() -> Period {
         Period { code: 0 }
     }
     pub fn get(_code: i32) -> Period {
